@@ -41,6 +41,8 @@ static gboolean draw_shape(GtkWidget *widget, GdkEventExpose *event,
    float_shape_t *s = (float_shape_t *)userdata;
    cairo_t *cr;
    int width, height;
+   GdkWindow *root_win;
+   GdkPixbuf *root_pb;
 
    cr = gdk_cairo_create(gtk_widget_get_window(widget));
 
@@ -48,6 +50,20 @@ static gboolean draw_shape(GtkWidget *widget, GdkEventExpose *event,
 
    gtk_window_get_size(GTK_WINDOW(widget), &width, &height);
 
+   if (!s->composited) {
+      // Gtk3 removed the gtk_widget_shape_combine_mask() function so to
+      // support transparency on a non-composited display we first
+      // capture the root window and use that as a backgroud for the
+      // floating shape.
+      root_win = gdk_get_default_root_window();
+      root_pb = gdk_pixbuf_get_from_window(root_win, s->x, s->y, width, height);
+
+      gdk_cairo_set_source_pixbuf(cr, root_pb, 0, 0);
+      cairo_paint(cr);
+
+      g_object_unref(root_pb);
+   }
+
    gdk_cairo_set_source_pixbuf(cr, s->pixbuf, 0, 0);
    cairo_paint(cr);
 
@@ -86,19 +102,18 @@ float_shape_t *make_shape_from_pixbuf(GdkPixbuf *pixbuf)
    gtk_window_set_keep_above(GTK_WINDOW(s->window), TRUE);
    gtk_window_set_resizable(GTK_WINDOW(s->window), FALSE);
    gtk_window_set_default_size(GTK_WINDOW(s->window), s->width, s->height);
+   gtk_widget_set_size_request(GTK_WIDGET(s->window), s->width, s->height);
 
    gtk_widget_set_app_paintable(GTK_WIDGET(s->window), TRUE);
 
    screen = gtk_widget_get_screen(s->window);
    visual = gdk_screen_get_rgba_visual(screen);
 
-   if (visual == NULL) {
-      fprintf(stderr, "Error: display does not support alpha channel\n");
-      exit(1);
+   if (gdk_screen_is_composited(screen) && visual) {
+      gtk_widget_set_visual(s->window, visual);
+      s->composited = true;
    }
 
-   gtk_widget_set_visual(s->window, visual);
-
    g_signal_connect(G_OBJECT(s->window), "draw",
                     G_CALLBACK(draw_shape), s);
    g_signal_connect(G_OBJECT(s->window), "screen-changed",
