@@ -1,5 +1,5 @@
 /*  xcowsay.c -- Cute talking cow for GTK+.
- *  Copyright (C) 2008-2010  Nick Gasson
+ *  Copyright (C) 2008-2020  Nick Gasson
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <limits.h>
 
 #include <sys/types.h>
+#include <sys/time.h>
 #include <unistd.h>
 #include <errno.h>
 
@@ -116,7 +117,7 @@ static void usage()
       "     --bubble-at=X,Y\t%s\n"
       "     --no-wrap\t\t%s\n"
       "     --config=FILE\t%s\n"
-      "     --debug\t\t%s\n\n"
+      "     --debug\t\t%s\n"
       "     --release\t\t%s\n\n"
       "%s\n\n"
       "%s\n\n"
@@ -154,7 +155,7 @@ static void usage()
 static void version()
 {
    static const char *copy =
-      "Copyright (C) 2008-2010  Nick Gasson\n"
+      "Copyright (C) 2008-2020  Nick Gasson\n"
       "This program comes with ABSOLUTELY NO WARRANTY. This is free software, and\n"
       "you are welcome to redistribute it under certain conditions. See the GNU\n"
       "General Public Licence for details.";
@@ -330,7 +331,9 @@ int main(int argc, char **argv)
    if (failure)
       exit(EXIT_FAILURE);
 
-   srandom((unsigned)time(NULL));
+   struct timeval tv;
+   gettimeofday(&tv, NULL);
+   srandom(tv.tv_sec ^ tv.tv_usec ^ getpid());
 
    cowmode_t mode = think_flag ? COWMODE_THINK : COWMODE_NORMAL;
 
